@@ -79,13 +79,13 @@ def compete_add(forest,network_ids=-1,radius_buffer=0.05,exact=True):
                                     closest_network = idx
                                     closest_distance = min(distances)
                         forest.networks[closest_network][np.random.choice(len(forest.networks[closest_network]))].rng_points.insert(-1,pt.tolist())
-                    print('End point reallocation: {}'.format(perf_counter()-start))
+                    #print('End point reallocation: {}'.format(perf_counter()-start))
                     ##
                     #print(len(forest.networks[nid][njd].rng_points))
                     #print("Check: {}".format(forest.networks[nid][njd].rng_points[0]))
                     start = perf_counter()
                     vessel,data,sub_division_map,sub_division_index,threshold = forest.networks[nid][njd].add(-1,0,isforest=True,radius_buffer=radius_buffer)
-                    print('End vessel appending: {}'.format(perf_counter()-start))
+                    #print('End vessel appending: {}'.format(perf_counter()-start))
                     point = data[-2,3:6] #new terminal point
                     #print(point)
                     #closest_network = nid
@@ -141,9 +141,9 @@ def compete_add(forest,network_ids=-1,radius_buffer=0.05,exact=True):
                                 break
                         if repeat:
                             break
-                    print('End collision testing: {}'.format(perf_counter()-start))
+                    #print('End collision testing: {}'.format(perf_counter()-start))
                     if repeat:
-                        print('repeating')
+                        #print('repeating')
                         #forest.networks[nid][njd] = deepcopy(networks_copy[nid][njd])
                         continue
                     else:
